pub struct Prose { /* private fields */ }Expand description
Top-level deserialized form of prose.toml.
The TOML file looks like [rules.<rule_name>] ..., which deserializes
as a single rules map keyed on rule name. BTreeMap rather than
HashMap so iteration order during validation tests is stable.
Implementations